@@ -94,9 +94,6 @@ def upgrade_163():
 
     op.execute("UPDATE v2_global_settings SET use_2d_rain = 1")
 
-    with op.batch_alter_table("v2_global_settings") as batch_op:
-        batch_op.alter_column("use_2d_rain", nullable=False)
-
 
 def upgrade_164():
     """This implements a migration from the old stack:
@@ -107,7 +104,7 @@ def upgrade_164():
         "v2_grid_refinement_area",
         sa.Column("id", sa.Integer(), nullable=False),
         sa.Column("display_name", sa.String(length=255), nullable=True),
-        sa.Column("refinement_level", sa.Integer(), nullable=False),
+        sa.Column("refinement_level", sa.Integer(), nullable=True),
         sa.Column("code", sa.String(length=100), nullable=True),
         sa.Column(
             "the_geom",
@@ -116,7 +113,7 @@ def upgrade_164():
                 srid=4326,
                 management=True,
             ),
-            nullable=False,
+            nullable=True,
         ),
         sa.PrimaryKeyConstraint("id"),
     )
@@ -184,7 +181,7 @@ def upgrade_165():
     create_table_if_not_exists(
         "v2_interflow",
         sa.Column("id", sa.Integer(), nullable=False),
-        sa.Column("interflow_type", sa.Integer(), nullable=False),
+        sa.Column("interflow_type", sa.Integer(), nullable=True),
         sa.Column("porosity", sa.Float(), nullable=True),
         sa.Column("porosity_file", sa.String(length=255), nullable=True),
         sa.Column("porosity_layer_thickness", sa.Float(), nullable=True),
@@ -310,10 +307,6 @@ def upgrade_171():
         "UPDATE v2_culvert SET discharge_coefficient_positive = 1.0 WHERE discharge_coefficient_positive IS NULL"
     )
 
-    with op.batch_alter_table("v2_culvert") as batch_op:
-        batch_op.alter_column("discharge_coefficient_negative", nullable=False)
-        batch_op.alter_column("discharge_coefficient_positive", nullable=False)
-
 
 def upgrade_172():
     """This implements a migration from the old stack:
@@ -375,7 +368,8 @@ def upgrade():
 
     # Initialize the Spatialite if necessary:
     if conn.dialect.name == "sqlite" and "spatial_ref_sys" not in existing_tables:
-        op.execute("SELECT InitSpatialMetadata()")
+        # The (1) performs the init in 1 transaction, which improves performance.
+        op.execute("SELECT InitSpatialMetadata(1)")
 
     version = _get_version(conn)
     if version is not None:
@@ -387,7 +381,7 @@ def upgrade():
         sa.Column("id", sa.Integer(), nullable=False),
         sa.Column("display_name", sa.String(length=255), nullable=True),
         sa.Column("timeseries", sa.Text(), nullable=True),
-        sa.Column("boundary_type", sa.Integer(), nullable=False),
+        sa.Column("boundary_type", sa.Integer(), nullable=True),
         sa.Column(
             "the_geom",
             geoalchemy2.types.Geometry(
@@ -395,14 +389,14 @@ def upgrade():
                 srid=4326,
                 management=True,
             ),
-            nullable=False,
+            nullable=True,
         ),
         sa.PrimaryKeyConstraint("id"),
     )
     create_table_if_not_exists(
         "v2_2d_lateral",
         sa.Column("id", sa.Integer(), nullable=False),
-        sa.Column("type", sa.Integer(), nullable=False),
+        sa.Column("type", sa.Integer(), nullable=True),
         sa.Column(
             "the_geom",
             geoalchemy2.types.Geometry(
@@ -410,16 +404,16 @@ def upgrade():
                 srid=4326,
                 management=True,
             ),
-            nullable=False,
+            nullable=True,
         ),
-        sa.Column("timeseries", sa.Text(), nullable=False),
+        sa.Column("timeseries", sa.Text(), nullable=True),
         sa.PrimaryKeyConstraint("id"),
     )
     create_table_if_not_exists(
         "v2_calculation_point",
         sa.Column("id", sa.Integer(), nullable=False),
         sa.Column("content_type_id", sa.Integer(), nullable=True),
-        sa.Column("user_ref", sa.String(length=80), nullable=False),
+        sa.Column("user_ref", sa.String(length=80), nullable=True),
         sa.Column("calc_type", sa.Integer(), nullable=True),
         sa.Column(
             "the_geom",
@@ -428,7 +422,7 @@ def upgrade():
                 srid=4326,
                 management=True,
             ),
-            nullable=False,
+            nullable=True,
         ),
         sa.PrimaryKeyConstraint("id"),
     )
@@ -444,7 +438,7 @@ def upgrade():
                 srid=4326,
                 management=True,
             ),
-            nullable=False,
+            nullable=True,
         ),
         sa.Column(
             "the_geom_linestring",
@@ -493,8 +487,8 @@ def upgrade():
         sa.Column("action_value", sa.String(length=50), nullable=True),
         sa.Column("target_type", sa.String(length=100), nullable=True),
         sa.Column("target_id", sa.Integer(), nullable=True),
-        sa.Column("is_active", sa.Boolean(), nullable=False),
-        sa.Column("is_inverse", sa.Boolean(), nullable=False),
+        sa.Column("is_active", sa.Boolean(), nullable=True),
+        sa.Column("is_inverse", sa.Boolean(), nullable=True),
         sa.PrimaryKeyConstraint("id"),
     )
     create_table_if_not_exists(
@@ -550,7 +544,7 @@ def upgrade():
                 srid=4326,
                 management=True,
             ),
-            nullable=False,
+            nullable=True,
         ),
         sa.PrimaryKeyConstraint("id"),
     )
@@ -573,7 +567,7 @@ def upgrade():
         "v2_grid_refinement",
         sa.Column("id", sa.Integer(), nullable=False),
         sa.Column("display_name", sa.String(length=255), nullable=True),
-        sa.Column("refinement_level", sa.Integer(), nullable=False),
+        sa.Column("refinement_level", sa.Integer(), nullable=True),
         sa.Column(
             "the_geom",
             geoalchemy2.types.Geometry(
@@ -581,7 +575,7 @@ def upgrade():
                 srid=4326,
                 management=True,
             ),
-            nullable=False,
+            nullable=True,
         ),
         sa.Column("code", sa.String(length=100), nullable=True),
         sa.PrimaryKeyConstraint("id"),
@@ -590,7 +584,7 @@ def upgrade():
         "v2_grid_refinement_area",
         sa.Column("id", sa.Integer(), nullable=False),
         sa.Column("display_name", sa.String(length=255), nullable=True),
-        sa.Column("refinement_level", sa.Integer(), nullable=False),
+        sa.Column("refinement_level", sa.Integer(), nullable=True),
         sa.Column("code", sa.String(length=100), nullable=True),
         sa.Column(
             "the_geom",
@@ -599,7 +593,7 @@ def upgrade():
                 srid=4326,
                 management=True,
             ),
-            nullable=False,
+            nullable=True,
         ),
         sa.PrimaryKeyConstraint("id"),
     )
@@ -650,8 +644,8 @@ def upgrade():
         sa.Column("id", sa.Integer(), nullable=False),
         sa.Column("code", sa.String(length=100), nullable=True),
         sa.Column("display_name", sa.String(length=255), nullable=True),
-        sa.Column("surface_inclination", sa.String(length=64), nullable=False),
-        sa.Column("surface_class", sa.String(length=128), nullable=False),
+        sa.Column("surface_inclination", sa.String(length=64), nullable=True),
+        sa.Column("surface_class", sa.String(length=128), nullable=True),
         sa.Column("surface_sub_class", sa.String(length=128), nullable=True),
         sa.Column("zoom_category", sa.Integer(), nullable=True),
         sa.Column("nr_of_inhabitants", sa.Float(), nullable=True),
@@ -671,7 +665,7 @@ def upgrade():
     create_table_if_not_exists(
         "v2_interflow",
         sa.Column("id", sa.Integer(), nullable=False),
-        sa.Column("interflow_type", sa.Integer(), nullable=False),
+        sa.Column("interflow_type", sa.Integer(), nullable=True),
         sa.Column("porosity", sa.Float(), nullable=True),
         sa.Column("porosity_file", sa.String(length=255), nullable=True),
         sa.Column("porosity_layer_thickness", sa.Float(), nullable=True),
@@ -693,7 +687,7 @@ def upgrade():
                 srid=4326,
                 management=True,
             ),
-            nullable=False,
+            nullable=True,
         ),
         sa.Column("material", sa.Integer(), nullable=True),
         sa.Column("max_breach_depth", sa.Float(), nullable=True),
@@ -715,22 +709,22 @@ def upgrade():
         sa.Column("limiter_slope_crossectional_area_2d", sa.Integer(), nullable=True),
         sa.Column("limiter_slope_friction_2d", sa.Integer(), nullable=True),
         sa.Column("max_nonlin_iterations", sa.Integer(), nullable=True),
-        sa.Column("max_degree", sa.Integer(), nullable=False),
+        sa.Column("max_degree", sa.Integer(), nullable=True),
         sa.Column("minimum_friction_velocity", sa.Float(), nullable=True),
         sa.Column("minimum_surface_area", sa.Float(), nullable=True),
         sa.Column("precon_cg", sa.Integer(), nullable=True),
         sa.Column("preissmann_slot", sa.Float(), nullable=True),
         sa.Column("pump_implicit_ratio", sa.Float(), nullable=True),
         sa.Column("thin_water_layer_definition", sa.Float(), nullable=True),
-        sa.Column("use_of_cg", sa.Integer(), nullable=False),
-        sa.Column("use_of_nested_newton", sa.Integer(), nullable=False),
+        sa.Column("use_of_cg", sa.Integer(), nullable=True),
+        sa.Column("use_of_nested_newton", sa.Integer(), nullable=True),
         sa.PrimaryKeyConstraint("id"),
     )
     create_table_if_not_exists(
         "v2_obstacle",
         sa.Column("id", sa.Integer(), nullable=False),
         sa.Column("code", sa.String(length=100), nullable=True),
-        sa.Column("crest_level", sa.Float(), nullable=False),
+        sa.Column("crest_level", sa.Float(), nullable=True),
         sa.Column(
             "the_geom",
             geoalchemy2.types.Geometry(
@@ -738,7 +732,7 @@ def upgrade():
                 srid=4326,
                 management=True,
             ),
-            nullable=False,
+            nullable=True,
         ),
         sa.PrimaryKeyConstraint("id"),
     )
@@ -755,29 +749,28 @@ def upgrade():
     create_table_if_not_exists(
         "v2_surface_parameters",
         sa.Column("id", sa.Integer(), nullable=False),
-        sa.Column("outflow_delay", sa.Float(), nullable=False),
-        sa.Column("surface_layer_thickness", sa.Float(), nullable=False),
-        sa.Column("infiltration", sa.Boolean(), nullable=False),
-        sa.Column("max_infiltration_capacity", sa.Float(), nullable=False),
-        sa.Column("min_infiltration_capacity", sa.Float(), nullable=False),
-        sa.Column("infiltration_decay_constant", sa.Float(), nullable=False),
-        sa.Column("infiltration_recovery_constant", sa.Float(), nullable=False),
+        sa.Column("outflow_delay", sa.Float(), nullable=True),
+        sa.Column("surface_layer_thickness", sa.Float(), nullable=True),
+        sa.Column("infiltration", sa.Boolean(), nullable=True),
+        sa.Column("max_infiltration_capacity", sa.Float(), nullable=True),
+        sa.Column("min_infiltration_capacity", sa.Float(), nullable=True),
+        sa.Column("infiltration_decay_constant", sa.Float(), nullable=True),
+        sa.Column("infiltration_recovery_constant", sa.Float(), nullable=True),
         sa.PrimaryKeyConstraint("id"),
     )
     create_table_if_not_exists(
         "v2_1d_boundary_conditions",
         sa.Column("id", sa.Integer(), nullable=False),
-        sa.Column("boundary_type", sa.Integer(), nullable=False),
+        sa.Column("boundary_type", sa.Integer(), nullable=True),
         sa.Column("timeseries", sa.Text(), nullable=True),
-        sa.Column("connection_node_id", sa.Integer(), nullable=False),
+        sa.Column("connection_node_id", sa.Integer(), nullable=True),
         sa.PrimaryKeyConstraint("id"),
-        sa.UniqueConstraint("connection_node_id"),
     )
     create_table_if_not_exists(
         "v2_1d_lateral",
         sa.Column("id", sa.Integer(), nullable=False),
-        sa.Column("connection_node_id", sa.Integer(), nullable=False),
-        sa.Column("timeseries", sa.Text(), nullable=False),
+        sa.Column("connection_node_id", sa.Integer(), nullable=True),
+        sa.Column("timeseries", sa.Text(), nullable=True),
         sa.PrimaryKeyConstraint("id"),
     )
     create_table_if_not_exists(
@@ -785,7 +778,7 @@ def upgrade():
         sa.Column("id", sa.Integer(), nullable=False),
         sa.Column("display_name", sa.String(length=255), nullable=True),
         sa.Column("code", sa.String(length=100), nullable=True),
-        sa.Column("calculation_type", sa.Integer(), nullable=False),
+        sa.Column("calculation_type", sa.Integer(), nullable=True),
         sa.Column("dist_calc_points", sa.Float(), nullable=True),
         sa.Column("zoom_category", sa.Integer(), nullable=True),
         sa.Column(
@@ -795,16 +788,16 @@ def upgrade():
                 srid=4326,
                 management=True,
             ),
-            nullable=False,
+            nullable=True,
         ),
-        sa.Column("connection_node_start_id", sa.Integer(), nullable=False),
-        sa.Column("connection_node_end_id", sa.Integer(), nullable=False),
+        sa.Column("connection_node_start_id", sa.Integer(), nullable=True),
+        sa.Column("connection_node_end_id", sa.Integer(), nullable=True),
         sa.PrimaryKeyConstraint("id"),
     )
     create_table_if_not_exists(
         "v2_connected_pnt",
         sa.Column("id", sa.Integer(), nullable=False),
-        sa.Column("calculation_pnt_id", sa.Integer(), nullable=False),
+        sa.Column("calculation_pnt_id", sa.Integer(), nullable=True),
         sa.Column("levee_id", sa.Integer(), nullable=True),
         sa.Column("exchange_level", sa.Float(), nullable=True),
         sa.Column(
@@ -814,7 +807,7 @@ def upgrade():
                 srid=4326,
                 management=True,
             ),
-            nullable=False,
+            nullable=True,
         ),
         sa.PrimaryKeyConstraint("id"),
     )
@@ -845,14 +838,14 @@ def upgrade():
         sa.Column("display_name", sa.String(length=255), nullable=True),
         sa.Column("code", sa.String(length=100), nullable=True),
         sa.Column("calculation_type", sa.Integer(), nullable=True),
-        sa.Column("friction_value", sa.Float(), nullable=False),
-        sa.Column("friction_type", sa.Integer(), nullable=False),
+        sa.Column("friction_value", sa.Float(), nullable=True),
+        sa.Column("friction_type", sa.Integer(), nullable=True),
         sa.Column("dist_calc_points", sa.Float(), nullable=True),
         sa.Column("zoom_category", sa.Integer(), nullable=True),
         sa.Column("discharge_coefficient_positive", sa.Float(), nullable=True),
         sa.Column("discharge_coefficient_negative", sa.Float(), nullable=True),
-        sa.Column("invert_level_start_point", sa.Float(), nullable=False),
-        sa.Column("invert_level_end_point", sa.Float(), nullable=False),
+        sa.Column("invert_level_start_point", sa.Float(), nullable=True),
+        sa.Column("invert_level_end_point", sa.Float(), nullable=True),
         sa.Column(
             "the_geom",
             geoalchemy2.types.Geometry(
@@ -862,45 +855,45 @@ def upgrade():
             ),
             nullable=True,
         ),
-        sa.Column("connection_node_start_id", sa.Integer(), nullable=False),
-        sa.Column("connection_node_end_id", sa.Integer(), nullable=False),
-        sa.Column("cross_section_definition_id", sa.Integer(), nullable=False),
+        sa.Column("connection_node_start_id", sa.Integer(), nullable=True),
+        sa.Column("connection_node_end_id", sa.Integer(), nullable=True),
+        sa.Column("cross_section_definition_id", sa.Integer(), nullable=True),
         sa.PrimaryKeyConstraint("id"),
     )
     create_table_if_not_exists(
         "v2_global_settings",
         sa.Column("id", sa.Integer(), nullable=False),
-        sa.Column("use_2d_flow", sa.Boolean(), nullable=False),
-        sa.Column("use_1d_flow", sa.Boolean(), nullable=False),
+        sa.Column("use_2d_flow", sa.Boolean(), nullable=True),
+        sa.Column("use_1d_flow", sa.Boolean(), nullable=True),
         sa.Column("manhole_storage_area", sa.Float(), nullable=True),
         sa.Column("name", sa.String(length=128), nullable=True),
-        sa.Column("sim_time_step", sa.Float(), nullable=False),
+        sa.Column("sim_time_step", sa.Float(), nullable=True),
         sa.Column("output_time_step", sa.Float(), nullable=True),
-        sa.Column("nr_timesteps", sa.Integer(), nullable=False),
+        sa.Column("nr_timesteps", sa.Integer(), nullable=True),
         sa.Column("start_time", sa.Text(), nullable=True),
-        sa.Column("start_date", sa.Text(), nullable=False),
-        sa.Column("grid_space", sa.Float(), nullable=False),
-        sa.Column("dist_calc_points", sa.Float(), nullable=False),
-        sa.Column("kmax", sa.Integer(), nullable=False),
+        sa.Column("start_date", sa.Text(), nullable=True),
+        sa.Column("grid_space", sa.Float(), nullable=True),
+        sa.Column("dist_calc_points", sa.Float(), nullable=True),
+        sa.Column("kmax", sa.Integer(), nullable=True),
         sa.Column("guess_dams", sa.Integer(), nullable=True),
-        sa.Column("table_step_size", sa.Float(), nullable=False),
-        sa.Column("flooding_threshold", sa.Float(), nullable=False),
-        sa.Column("advection_1d", sa.Integer(), nullable=False),
-        sa.Column("advection_2d", sa.Integer(), nullable=False),
+        sa.Column("table_step_size", sa.Float(), nullable=True),
+        sa.Column("flooding_threshold", sa.Float(), nullable=True),
+        sa.Column("advection_1d", sa.Integer(), nullable=True),
+        sa.Column("advection_2d", sa.Integer(), nullable=True),
         sa.Column("dem_file", sa.String(length=255), nullable=True),
         sa.Column("frict_type", sa.Integer(), nullable=True),
-        sa.Column("frict_coef", sa.Float(), nullable=False),
+        sa.Column("frict_coef", sa.Float(), nullable=True),
         sa.Column("frict_coef_file", sa.String(length=255), nullable=True),
         sa.Column("water_level_ini_type", sa.Integer(), nullable=True),
-        sa.Column("initial_waterlevel", sa.Float(), nullable=False),
+        sa.Column("initial_waterlevel", sa.Float(), nullable=True),
         sa.Column("initial_waterlevel_file", sa.String(length=255), nullable=True),
         sa.Column("interception_global", sa.Float(), nullable=True),
         sa.Column("interception_file", sa.String(length=255), nullable=True),
-        sa.Column("dem_obstacle_detection", sa.Boolean(), nullable=False),
+        sa.Column("dem_obstacle_detection", sa.Boolean(), nullable=True),
         sa.Column("dem_obstacle_height", sa.Float(), nullable=True),
         sa.Column("embedded_cutoff_threshold", sa.Float(), nullable=True),
         sa.Column("epsg_code", sa.Integer(), nullable=True),
-        sa.Column("timestep_plus", sa.Boolean(), nullable=False),
+        sa.Column("timestep_plus", sa.Boolean(), nullable=True),
         sa.Column("max_angle_1d_advection", sa.Float(), nullable=True),
         sa.Column("minimum_sim_time_step", sa.Float(), nullable=True),
         sa.Column("maximum_sim_time_step", sa.Float(), nullable=True),
@@ -909,13 +902,13 @@ def upgrade():
         sa.Column("use_0d_inflow", sa.Integer(), nullable=True),
         sa.Column("table_step_size_1d", sa.Float(), nullable=True),
         sa.Column("table_step_size_volume_2d", sa.Float(), nullable=True),
-        sa.Column("use_2d_rain", sa.Integer(), nullable=False),
+        sa.Column("use_2d_rain", sa.Integer(), nullable=True),
         sa.Column("initial_groundwater_level", sa.Float(), nullable=True),
         sa.Column(
             "initial_groundwater_level_file", sa.String(length=255), nullable=True
         ),
         sa.Column("initial_groundwater_level_type", sa.Integer(), nullable=True),
-        sa.Column("numerical_settings_id", sa.Integer(), nullable=False),
+        sa.Column("numerical_settings_id", sa.Integer(), nullable=True),
         sa.Column("interflow_settings_id", sa.Integer(), nullable=True),
         sa.Column("control_group_id", sa.Integer(), nullable=True),
         sa.Column("simple_infiltration_settings_id", sa.Integer(), nullable=True),
@@ -925,9 +918,9 @@ def upgrade():
     create_table_if_not_exists(
         "v2_impervious_surface_map",
         sa.Column("id", sa.Integer(), nullable=False),
-        sa.Column("percentage", sa.Float(), nullable=False),
-        sa.Column("impervious_surface_id", sa.Integer(), nullable=False),
-        sa.Column("connection_node_id", sa.Integer(), nullable=False),
+        sa.Column("percentage", sa.Float(), nullable=True),
+        sa.Column("impervious_surface_id", sa.Integer(), nullable=True),
+        sa.Column("connection_node_id", sa.Integer(), nullable=True),
         sa.PrimaryKeyConstraint("id"),
     )
     create_table_if_not_exists(
@@ -940,12 +933,12 @@ def upgrade():
         sa.Column("width", sa.Float(), nullable=True),
         sa.Column("length", sa.Float(), nullable=True),
         sa.Column("surface_level", sa.Float(), nullable=True),
-        sa.Column("bottom_level", sa.Float(), nullable=False),
+        sa.Column("bottom_level", sa.Float(), nullable=True),
         sa.Column("drain_level", sa.Float(), nullable=True),
         sa.Column("sediment_level", sa.Float(), nullable=True),
         sa.Column("manhole_indicator", sa.Integer(), nullable=True),
         sa.Column("calculation_type", sa.Integer(), nullable=True),
-        sa.Column("connection_node_id", sa.Integer(), nullable=False),
+        sa.Column("connection_node_id", sa.Integer(), nullable=True),
         sa.PrimaryKeyConstraint("id"),
     )
     create_table_if_not_exists(
@@ -954,16 +947,16 @@ def upgrade():
         sa.Column("code", sa.String(length=100), nullable=True),
         sa.Column("display_name", sa.String(length=255), nullable=True),
         sa.Column("zoom_category", sa.Integer(), nullable=True),
-        sa.Column("crest_type", sa.Integer(), nullable=False),
-        sa.Column("crest_level", sa.Float(), nullable=False),
+        sa.Column("crest_type", sa.Integer(), nullable=True),
+        sa.Column("crest_level", sa.Float(), nullable=True),
         sa.Column("friction_value", sa.Float(), nullable=True),
         sa.Column("friction_type", sa.Integer(), nullable=True),
         sa.Column("discharge_coefficient_positive", sa.Float(), nullable=True),
         sa.Column("discharge_coefficient_negative", sa.Float(), nullable=True),
-        sa.Column("sewerage", sa.Boolean(), nullable=False),
-        sa.Column("connection_node_start_id", sa.Integer(), nullable=False),
-        sa.Column("connection_node_end_id", sa.Integer(), nullable=False),
-        sa.Column("cross_section_definition_id", sa.Integer(), nullable=False),
+        sa.Column("sewerage", sa.Boolean(), nullable=True),
+        sa.Column("connection_node_start_id", sa.Integer(), nullable=True),
+        sa.Column("connection_node_end_id", sa.Integer(), nullable=True),
+        sa.Column("cross_section_definition_id", sa.Integer(), nullable=True),
         sa.PrimaryKeyConstraint("id"),
     )
     create_table_if_not_exists(
@@ -973,18 +966,18 @@ def upgrade():
         sa.Column("code", sa.String(length=100), nullable=True),
         sa.Column("profile_num", sa.Integer(), nullable=True),
         sa.Column("sewerage_type", sa.Integer(), nullable=True),
-        sa.Column("calculation_type", sa.Integer(), nullable=False),
-        sa.Column("invert_level_start_point", sa.Float(), nullable=False),
-        sa.Column("invert_level_end_point", sa.Float(), nullable=False),
-        sa.Column("friction_value", sa.Float(), nullable=False),
-        sa.Column("friction_type", sa.Integer(), nullable=False),
+        sa.Column("calculation_type", sa.Integer(), nullable=True),
+        sa.Column("invert_level_start_point", sa.Float(), nullable=True),
+        sa.Column("invert_level_end_point", sa.Float(), nullable=True),
+        sa.Column("friction_value", sa.Float(), nullable=True),
+        sa.Column("friction_type", sa.Integer(), nullable=True),
         sa.Column("dist_calc_points", sa.Float(), nullable=True),
         sa.Column("material", sa.Integer(), nullable=True),
         sa.Column("original_length", sa.Float(), nullable=True),
         sa.Column("zoom_category", sa.Integer(), nullable=True),
-        sa.Column("connection_node_start_id", sa.Integer(), nullable=False),
-        sa.Column("connection_node_end_id", sa.Integer(), nullable=False),
-        sa.Column("cross_section_definition_id", sa.Integer(), nullable=False),
+        sa.Column("connection_node_start_id", sa.Integer(), nullable=True),
+        sa.Column("connection_node_end_id", sa.Integer(), nullable=True),
+        sa.Column("cross_section_definition_id", sa.Integer(), nullable=True),
         sa.PrimaryKeyConstraint("id"),
     )
     create_table_if_not_exists(
@@ -995,12 +988,12 @@ def upgrade():
         sa.Column("zoom_category", sa.Integer(), nullable=True),
         sa.Column("classification", sa.Integer(), nullable=True),
         sa.Column("sewerage", sa.Boolean(), nullable=True),
-        sa.Column("type", sa.Integer(), nullable=False),
-        sa.Column("start_level", sa.Float(), nullable=False),
-        sa.Column("lower_stop_level", sa.Float(), nullable=False),
+        sa.Column("type", sa.Integer(), nullable=True),
+        sa.Column("start_level", sa.Float(), nullable=True),
+        sa.Column("lower_stop_level", sa.Float(), nullable=True),
         sa.Column("upper_stop_level", sa.Float(), nullable=True),
-        sa.Column("capacity", sa.Float(), nullable=False),
-        sa.Column("connection_node_start_id", sa.Integer(), nullable=False),
+        sa.Column("capacity", sa.Float(), nullable=True),
+        sa.Column("connection_node_start_id", sa.Integer(), nullable=True),
         sa.Column("connection_node_end_id", sa.Integer(), nullable=True),
         sa.PrimaryKeyConstraint("id"),
     )
@@ -1014,7 +1007,7 @@ def upgrade():
         sa.Column("dry_weather_flow", sa.Float(), nullable=True),
         sa.Column("function", sa.String(length=64), nullable=True),
         sa.Column("area", sa.Float(), nullable=True),
-        sa.Column("surface_parameters_id", sa.Integer(), nullable=False),
+        sa.Column("surface_parameters_id", sa.Integer(), nullable=True),
         sa.Column(
             "the_geom",
             geoalchemy2.types.Geometry(
@@ -1029,9 +1022,9 @@ def upgrade():
     create_table_if_not_exists(
         "v2_surface_map",
         sa.Column("id", sa.Integer(), nullable=False),
-        sa.Column("surface_type", sa.String(length=40), nullable=False),
-        sa.Column("surface_id", sa.Integer(), nullable=False),
-        sa.Column("connection_node_id", sa.Integer(), nullable=False),
+        sa.Column("surface_type", sa.String(length=40), nullable=True),
+        sa.Column("surface_id", sa.Integer(), nullable=True),
+        sa.Column("connection_node_id", sa.Integer(), nullable=True),
         sa.Column("percentage", sa.Float(), nullable=True),
         sa.PrimaryKeyConstraint("id"),
     )
@@ -1040,8 +1033,8 @@ def upgrade():
         sa.Column("id", sa.Integer(), nullable=False),
         sa.Column("code", sa.String(length=100), nullable=True),
         sa.Column("display_name", sa.String(length=255), nullable=True),
-        sa.Column("crest_level", sa.Float(), nullable=False),
-        sa.Column("crest_type", sa.Integer(), nullable=False),
+        sa.Column("crest_level", sa.Float(), nullable=True),
+        sa.Column("crest_type", sa.Integer(), nullable=True),
         sa.Column("friction_value", sa.Float(), nullable=True),
         sa.Column("friction_type", sa.Integer(), nullable=True),
         sa.Column("discharge_coefficient_positive", sa.Float(), nullable=True),
@@ -1049,29 +1042,29 @@ def upgrade():
         sa.Column("sewerage", sa.Boolean(), nullable=True),
         sa.Column("external", sa.Boolean(), nullable=True),
         sa.Column("zoom_category", sa.Integer(), nullable=True),
-        sa.Column("connection_node_start_id", sa.Integer(), nullable=False),
-        sa.Column("connection_node_end_id", sa.Integer(), nullable=False),
-        sa.Column("cross_section_definition_id", sa.Integer(), nullable=False),
+        sa.Column("connection_node_start_id", sa.Integer(), nullable=True),
+        sa.Column("connection_node_end_id", sa.Integer(), nullable=True),
+        sa.Column("cross_section_definition_id", sa.Integer(), nullable=True),
         sa.PrimaryKeyConstraint("id"),
     )
     create_table_if_not_exists(
         "v2_aggregation_settings",
         sa.Column("id", sa.Integer(), nullable=False),
         sa.Column("global_settings_id", sa.Integer(), nullable=True),
-        sa.Column("var_name", sa.String(length=100), nullable=False),
-        sa.Column("flow_variable", sa.String(length=100), nullable=False),
+        sa.Column("var_name", sa.String(length=100), nullable=True),
+        sa.Column("flow_variable", sa.String(length=100), nullable=True),
         sa.Column("aggregation_method", sa.String(length=100), nullable=True),
-        sa.Column("aggregation_in_space", sa.Boolean(), nullable=False),
-        sa.Column("timestep", sa.Integer(), nullable=False),
+        sa.Column("aggregation_in_space", sa.Boolean(), nullable=True),
+        sa.Column("timestep", sa.Integer(), nullable=True),
         sa.PrimaryKeyConstraint("id"),
     )
     create_table_if_not_exists(
         "v2_cross_section_location",
         sa.Column("id", sa.Integer(), nullable=False),
         sa.Column("code", sa.String(length=100), nullable=True),
-        sa.Column("reference_level", sa.Float(), nullable=False),
-        sa.Column("friction_type", sa.Integer(), nullable=False),
-        sa.Column("friction_value", sa.Float(), nullable=False),
+        sa.Column("reference_level", sa.Float(), nullable=True),
+        sa.Column("friction_type", sa.Integer(), nullable=True),
+        sa.Column("friction_value", sa.Float(), nullable=True),
         sa.Column("bank_level", sa.Float(), nullable=True),
         sa.Column(
             "the_geom",
@@ -1080,10 +1073,10 @@ def upgrade():
                 srid=4326,
                 management=True,
             ),
-            nullable=False,
+            nullable=True,
         ),
-        sa.Column("channel_id", sa.Integer(), nullable=False),
-        sa.Column("definition_id", sa.Integer(), nullable=False),
+        sa.Column("channel_id", sa.Integer(), nullable=True),
+        sa.Column("definition_id", sa.Integer(), nullable=True),
         sa.PrimaryKeyConstraint("id"),
     )
     create_table_if_not_exists(
@@ -1106,7 +1099,7 @@ def upgrade():
             ),
             nullable=True,
         ),
-        sa.Column("channel_id", sa.Integer(), nullable=False),
+        sa.Column("channel_id", sa.Integer(), nullable=True),
         sa.PrimaryKeyConstraint("id"),
     )
 
