@@ -1,7 +1,10 @@
 from .errors import MigrationMissingError
+from .spatialite_versions import copy_models
+from .spatialite_versions import get_spatialite_version
 from .threedi_model import constants
 from .threedi_model import models
 from .threedi_model import views
+from alembic import command as alembic_command
 from alembic.config import Config
 from alembic.environment import EnvironmentContext
 from alembic.migration import MigrationContext
@@ -34,23 +37,44 @@ def get_schema_version():
         return int(env.get_head_revision())
 
 
-def _upgrade_database(db, revision="head"):
+def _upgrade_database(db, revision="head", unsafe=True):
     """Upgrade ThreediDatabase instance"""
-    with db.get_engine().begin() as connection:
+    engine = db.get_engine()
+
+    with engine.begin() as connection:
+        if unsafe:
+            # Speed up by journalling in memory; in case of a crash the database
+            # will likely go corrupt.
+            # NB: This setting is scoped to this connection.
+            connection.execute("PRAGMA journal_mode = MEMORY")
         config = get_alembic_config(connection)
-        script = ScriptDirectory.from_config(config)
+        alembic_command.upgrade(config, revision)
 
-        def upgrade(rev, context):
-            return script._upgrade_revs(revision, rev)
 
-        with EnvironmentContext(
-            config,
-            script,
-            fn=upgrade,
-            destination_rev=revision,
-            version_table=constants.VERSION_TABLE_NAME,
-        ):
-            script.run_env()
+def _recreate_views(db, file_version):
+    """Recreate predefined views in a ThreediDatabase instance"""
+    engine = db.get_engine()
+
+    with engine.begin() as connection:
+        for (name, view) in views.ALL_VIEWS.items():
+            connection.execute(f"DROP VIEW IF EXISTS {name}")
+            connection.execute(
+                f"DELETE FROM views_geometry_columns WHERE view_name = '{name}'"
+            )
+            connection.execute(f"CREATE VIEW {name} AS {view['definition']}")
+            if file_version == 3:
+                connection.execute(
+                    f"INSERT INTO views_geometry_columns (view_name, view_geometry,view_rowid,f_table_name,f_geometry_column) VALUES('{name}', '{view['view_geometry']}', '{view['view_rowid']}', '{view['f_table_name']}', '{view['f_geometry_column']}')"
+                )
+            else:
+                connection.execute(
+                    f"INSERT INTO views_geometry_columns (view_name, view_geometry,view_rowid,f_table_name,f_geometry_column,read_only) VALUES('{name}', '{view['view_geometry']}', '{view['view_rowid']}', '{view['f_table_name']}', '{view['f_geometry_column']}', 0)"
+                )
+        for name in views.VIEWS_TO_DELETE:
+            connection.execute(f"DROP VIEW IF EXISTS {name}")
+            connection.execute(
+                f"DELETE FROM views_geometry_columns WHERE view_name = '{name}'"
+            )
 
 
 class ModelSchema:
@@ -89,7 +113,13 @@ class ModelSchema:
         else:
             return self._get_version_old()
 
-    def upgrade(self, revision="head", backup=True, set_views=True):
+    def upgrade(
+        self,
+        revision="head",
+        backup=True,
+        set_views=True,
+        upgrade_spatialite_version=False,
+    ):
         """Upgrade the database to the latest version.
 
         This requires either a completely empty database or a database with its
@@ -105,7 +135,14 @@ class ModelSchema:
         Specify 'set_views=True' to also (re)create views after the upgrade.
         This is not compatible when upgrading to a different version than the
         latest version.
+
+        Specify 'upgrade_spatialite_version=True' to also upgrade the
+        spatialite file version after the upgrade.
         """
+        if upgrade_spatialite_version and not set_views:
+            raise ValueError(
+                "Cannot upgrade the spatialite version without setting the views."
+            )
         v = self.get_version()
         if v is not None and v < constants.LATEST_SOUTH_MIGRATION_ID:
             raise MigrationMissingError(
@@ -117,11 +154,13 @@ class ModelSchema:
             raise ValueError(f"Cannot set views when upgrading to version '{revision}'")
         if backup:
             with self.db.file_transaction() as work_db:
-                _upgrade_database(work_db, revision=revision)
+                _upgrade_database(work_db, revision=revision, unsafe=True)
         else:
-            _upgrade_database(self.db, revision=revision)
+            _upgrade_database(self.db, revision=revision, unsafe=False)
 
-        if set_views:
+        if upgrade_spatialite_version:
+            self.upgrade_spatialite_version()
+        elif set_views:
             self.set_views()
 
     def validate_schema(self):
@@ -160,24 +199,30 @@ class ModelSchema:
         """(Re)create views in the spatialite according to the latest definitions."""
         version = self.get_version()
         schema_version = get_schema_version()
-        if version != get_schema_version():
+        if version != schema_version:
             raise MigrationMissingError(
                 f"Setting views requires schema version "
                 f"{schema_version}. Current version: {version}."
             )
 
-        with self.db.get_engine().begin() as connection:
-            for (name, view) in views.ALL_VIEWS.items():
-                connection.execute(f"DROP VIEW IF EXISTS {name}")
-                connection.execute(
-                    f"DELETE FROM views_geometry_columns WHERE view_name = '{name}'"
-                )
-                connection.execute(f"CREATE VIEW {name} AS {view['definition']}")
-                connection.execute(
-                    f"INSERT INTO views_geometry_columns (view_name, view_geometry,view_rowid,f_table_name,f_geometry_column) VALUES('{name}', '{view['view_geometry']}', '{view['view_rowid']}', '{view['f_table_name']}', '{view['f_geometry_column']}')"
-                )
-            for name in views.VIEWS_TO_DELETE:
-                connection.execute(f"DROP VIEW IF EXISTS {name}")
-                connection.execute(
-                    f"DELETE FROM views_geometry_columns WHERE view_name = '{name}'"
-                )
+        _, file_version = get_spatialite_version(self.db)
+
+        _recreate_views(self.db, file_version)
+
+    def upgrade_spatialite_version(self):
+        """Upgrade the version of the spatialite file to the version of the
+        current spatialite library.
+
+        Does nothing if the current file version > 3 or if the current library
+        version is not 4 or 5.
+
+        Raises UpgradeFailedError if there are any SQL constraints violated.
+        """
+        lib_version, file_version = get_spatialite_version(self.db)
+        if file_version == 3 and lib_version in (4, 5):
+            self.validate_schema()
+
+            with self.db.file_transaction(start_empty=True) as work_db:
+                _upgrade_database(work_db, revision="head", unsafe=True)
+                _recreate_views(work_db, file_version=4)
+                copy_models(self.db, work_db, self.declared_models)
